// Hartman & Newmark (2012), analysis of undergraduate sample for
// "Motivated reasoning, political sophistication, and associations between President Obama and Islam" 
// Note: D-score variable already corrected for flipped (randomized) config file, but actual RT's and other IAT measures are not

// Describe Data
describe

//*** EXPLICIT MEASURES ***//
//* Obama's Religion
tab obamarel
// Dummy Variable: Obama is a Muslim
recode obamarel (1=0)(2=0)(3=1)(4=0)(5=0)(6=0)(7=0)(8=0),gen(bomuslim)
tab bomuslim
// Dummy Variable: Correctly Identified Obama is Christian
recode obamarel (1=1)(2=0)(3=0)(4=0)(5=0)(6=0)(7=0)(8=0),gen(bochrist)
tab bochrist

//* Likelihood Obama is Muslim
tab obamarel3
recode obamarel3 (1=4)(2=3)(3=2)(4=1), gen(bomuslim2)
tab bomuslim2
replace bomuslim2 = (bomuslim2-1)/3
tab bomuslim2

//* Relative Evaluation of Obama (Obama FT minus McCain FT)
sum ft_obama
sum ft_mccain
gen ft_bojm = (ft_obama - ft_mccain)/100
tab ft_bojm
replace ft_bojm = (ft_bojm+1)/2
sum ft_bojm, det
tab ft_bojm

//* 8-item Political Knowledge Scale
tab know1
recode know1 (1=0)(2=0)(3=1)(4=0)(.=0), gen(kn1)
tab kn1

tab know2
recode know2 (1=0)(2=0)(3=0)(4=1)(5=0)(.=0), gen(kn2)
tab kn2

tab know3
recode know3 (1=0)(2=0)(3=1)(4=0)(5=0)(6=0)(7=0)(.=0), gen(kn3)
tab kn3

tab know4
recode know4 (1=0)(2=1)(3=0)(4=0)(.=0), gen(kn4)
tab kn4

tab know5
gen kn5 = 999
replace kn5 = 1 if know5==9
replace kn5 = 0 if know5~=9
tab kn5

tab know6
recode know6 (1=1)(2=0)(3=0)(4=0)(5=0)(6=0)(.=0), gen(kn6)
tab kn6

tab know7
recode know7 (1=0)(2=0)(3=1)(4=0)(.=0), gen(kn7)
tab kn7

tab know8
recode know8 (1=1)(2=0)(3=0)(4=0)(5=0)(.=0), gen(kn8)
tab kn8

corr kn1 kn2 kn3 kn4 kn5 kn6 kn7 kn8
alpha kn1 kn2 kn3 kn4 kn5 kn6 kn7 kn8, item det
kr20 kn1 kn2 kn3 kn4 kn5 kn6 kn7 kn8

gen polknow = kn1 + kn2 + kn3 + kn4 + kn5 + kn6 + kn7 + kn8
tab polknow
replace polknow = polknow/8
tab polknow

// Trichotomized Political Knowledge Scale (Tertile split)
gen polknow3 = 999
replace polknow3 =1 if polknow<=.375
replace polknow3 =2 if polknow>.375 & polknow<=.625
replace polknow3 = 3 if polknow>.625 & polknow<2
tab polknow3
replace polknow3 = . if polknow3==999

//* Dummy Variable for Gender (1=Male)
tab gender
recode gender (1=1)(2=0), gen(male)
tab male

//* Dummy Variable for Race (1=Nonwhite)
tab race
recode race (1=0)(2=1)(3=1)(4=1)(5=1)(6=1), gen(nonwhite)
replace nonwhite = . if id==1129 | id==1272
tab nonwhite

//* 5-pt. Party Identification Scale (1= Strong Republican)
tab pid
recode pid (1=5)(2=4)(3=3)(4=2)(5=1), gen(partyid)
tab partyid
replace partyid = (partyid - 1)/4
tab partyid

//* 5-pt. Ideology Scale (1=Very Conservative)
tab ideology
gen ideolog = (ideology-1)/4

corr ft_bojm pid ideology

//*** IMPLICIT MEASURES ***//
//* Overall D-Score (IAT Effect)
sum d_iateff, det

pwcorr bochrist bomuslim2 d_iateff, sig obs star(.05) 

// Mean RT Difference: Corrected Block 5 - Block 3 (Obama-Christian minus Obama-Muslim)
gen rtdiff = .
replace rtdiff =  rt_corr5 -  rt_corr3 if config==1
replace rtdiff =  rt_corr3 -  rt_corr5 if config==0

//*** Table 1: MEAN DIFFERENCES
tab1 bochrist bomuslim2
sum d_iateff rtdiff

// Mean IAT Effect by PID
tab pid
recode pid (1=3)(2=3)(3=2)(4=1)(5=1), gen(party)
tab party bochrist, row
tab party bomuslim2, row
table party, c(mean d_iateff n d_iateff)
table party, c(mean rtdiff n rtdiff)

// Mean IAT Effect by Ideology
tab ideology
recode ideology (1=1)(2=1)(3=2)(4=3)(5=3), gen(ideo)
tab ideo bochrist, row
tab ideo bomuslim2, row
table ideo, c(mean d_iateff n d_iateff)
table ideo, c(mean rtdiff n rtdiff)

// Mean IAT effect by Evaluations of Candidates
tab ft_obama
tab ft_mccain
gen ft_bojm2 = ft_obama - ft_mccain
gen bodiff = 999
replace bodiff = 1 if ft_bojm2>0 & ft_bojm2<999
replace bodiff = 0 if ft_bojm2<0
tab bodiff
replace bodiff = . if bodiff==999
tab bodiff

tab bodiff bochrist, row
tab bodiff bomuslim2, row
table bodiff, c(mean d_iateff n d_iateff)
table bodiff, c(mean rtdiff n rtdiff)

// Mean IAT effect by Political Sophistication
tab polknow3 bochrist, row
tab polknow3 bomuslim2, row
table polknow3, c(mean d_iateff n d_iateff)
table polknow3, c(mean rtdiff n rtdiff)

// Mean IAT effect by Race
tab nonwhite bochrist, row
tab nonwhite bomuslim2, row
table nonwhite, c(mean d_iateff n d_iateff)
table nonwhite, c(mean rtdiff n rtdiff)

// Mean IAT effect by Gender
tab gender bochrist, row
tab gender bomuslim2, row
table gender, c(mean d_iateff n d_iateff)
table gender, c(mean rtdiff n rtdiff)

// Mean IAT effect by Correct Religion
table bochrist, c(mean d_iateff n d_iateff)
table bochrist, c(mean rtdiff n rtdiff)

// Mean IAT effect by Obama Likely Muslim
tab obamarel3
recode obamarel3 (1=1)(2=1)(3=0)(4=0), gen(bomuslim3)
tab bomuslim3
table bomuslim3, c(mean d_iateff n d_iateff)
table bomuslim3, c(mean rtdiff n rtdiff)

//*** REGRESSION ANALYSES
//** Parsimonious Models -- Tests for mediation done in MPLUS
//* Model Determining Who Correctly Identified Obama's Religion as Christian
logit bochrist partyid ideolog polknow male nonwhite, robust
estout using "C:\Temp\out1.txt", cells ("b(star fmt(2)) se(par fm(2))") starlevels(+ 0.10 * 0.05 ** 0.01) type replace

//* Model Determining Who Believes Obama Is a Muslim
ologit bomuslim2 partyid ideolog polknow male nonwhite, robust
estout using "C:\Temp\out1.txt", cells ("b(star fmt(2)) se(par fm(2))") starlevels(+ 0.10 * 0.05 ** 0.01) type append

//* Model of IAT Effect (D-Score)
reg d_iateff partyid ideolog polknow male nonwhite, robust
estout using "C:\Temp\out1.txt", cells ("b(star fmt(2)) se(par fm(2))") starlevels(+ 0.10 * 0.05 ** 0.01) type append

//* Predicted Probabilities
//* Ideology
logit bochrist partyid ideolog polknow male nonwhite, robust
prvalue, x(ideolog=0 male=0 nonwhite=0) rest(mean)
prvalue, x(ideolog=1 male=0 nonwhite=0) rest(mean)

recode obamarel3 (1=4)(2=3)(3=2)(4=1), gen(bomuslim2pr)
ologit bomuslim2pr partyid ideolog polknow male nonwhite, robust
prvalue, x(ideolog=0 male=0 nonwhite=0) rest(mean)
prvalue, x(ideolog=1 male=0 nonwhite=0) rest(mean)

reg d_iateff partyid ideolog polknow male nonwhite, robust
prvalue, x(ideolog=0 male=0 nonwhite=0) rest(mean)
prvalue, x(ideolog=1 male=0 nonwhite=0) rest(mean)

//* Predicted Probabilities
//* Party ID
ologit bomuslim2pr partyid ideolog polknow male nonwhite, robust
prvalue, x(partyid=0 male=0 nonwhite=0) rest(mean)
prvalue, x(partyid=1 male=0 nonwhite=0) rest(mean)

reg d_iateff partyid ideolog polknow male nonwhite, robust
prvalue, x(partyid=0 male=0 nonwhite=0) rest(mean)
prvalue, x(partyid=1 male=0 nonwhite=0) rest(mean)

//* Predicted Probabilities
//* Political Sophistication
logit bochrist partyid ideolog polknow male nonwhite, robust
prvalue, x(polknow=0 male=0 nonwhite=0) rest(mean)
prvalue, x(polknow=1 male=0 nonwhite=0) rest(mean)

ologit bomuslim2pr partyid ideolog polknow male nonwhite, robust
prvalue, x(polknow=0 male=0 nonwhite=0) rest(mean)
prvalue, x(polknow=1 male=0 nonwhite=0) rest(mean)

reg d_iateff partyid ideolog polknow male nonwhite, robust
prvalue, x(polknow=0 male=0 nonwhite=0) rest(mean)
prvalue, x(polknow=1 male=0 nonwhite=0) rest(mean)

//* Create MPlus Dataset
stata2mplus  d_iateff  bochrist bomuslim2 ft_bojm kn1 kn2 kn3 kn4 kn5 kn6 kn7 kn8 polknow male nonwhite partyid ideolog using C:\Temp\hartman_newmark_mplus , replace
